inlaQ: Define the method to extract the precision from an inla...

View source: R/inla_methods.R

inlaQR Documentation

Define the method to extract the precision from an inla output object.

Description

Define the method to extract the precision from an inla output object.

Usage

inlaQ(model, ...)

Arguments

model

an inla output

...

used to pass the 'prior' argument, as logical (default is TRUE) to indicate if it is to retrieve the prior or the posterior precision.

Details

extract the joint prior precision for the latent field at the mode of the hyperparameters


INLAtools documentation built on May 4, 2026, 5:07 p.m.

Related to inlaQ in INLAtools...