| multi_generic_model | R Documentation |
cgeneric or rgeneric modelsConstructs a multiple kronecker product model from a list of model
objects. The resulting model contains a corresponding inlabru::bm_multi()
mapper. This can be used as an alternative to a binary tree of kronecker
product models.
multi_generic_model(models, ...)
multi_generic_model_mapper(models)
models |
A list of |
... |
Arguments passed on to every |
The last model in the list has the slowest index variation, and the
first model has the fastest index variation. This matches the latent
variable ordering of standard INLA:f() model components with
(main, group, replicate).
A 'cgeneric' or 'rgeneric' model object, containing a
multi-kronecker product model, with a corresponding inlabru::bm_multi()
mapper.
multi_generic_model_mapper(): Buidl the bm_multi mapper for a list of models
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.