prec.inla: Define the prec method for an inla output object

View source: R/inla_methods.R

prec.inlaR Documentation

Define the prec method for an inla output object

Description

Define the prec method for an inla output object

Usage

## S3 method for class 'inla'
prec(model, ...)

Arguments

model

an inla output

...

used to pass the 'prior' argument, as logical (default is TRUE) to indicate if it is to retrieve the prior or the posterior precision.

Details

extract the joint prior precision for the latent field at the mode of the hyperparameters


INLAtools documentation built on Feb. 12, 2026, 5:07 p.m.