| inlaQ | R Documentation |
Define the method to extract the precision from an inla output object.
inlaQ(model, ...)
model |
an inla output |
... |
used to pass the 'prior' argument, as logical (default is TRUE) to indicate if it is to retrieve the prior or the posterior precision. |
extract the joint prior precision for the latent field at the mode of the hyperparameters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.