| pc-utils | R Documentation |
Internal functions to check PC-prior parameters.
pcParamCheck(npars, reference, probability)
pclrange(lrange, lam, d = 2, log = FALSE)
pcrange(range, lam, d = 2, log = FALSE)
npars |
number of parameters. |
reference |
numeric vector to set the reference for each parameter for its PC-prior. |
probability |
numeric vector with to
set the probability statement of the PC prior for each
parameter. For |
lrange |
numeric with the log of the (practical) range |
lam |
numeric with the prior parameter |
d |
integer to specify the domain dimention |
log |
logical indicating if the density is to be returned in the log scale |
range |
numeric with the of the (practical) range. |
pcParamCheck(): Check the PC-prior arguments.
pclrange(): Penalized Complexity (PC) prior for the log of the practical range.
pcrange(): Penalized Complexity (PC) prior for the practical range.
# P(range < 2.0) = 0.1
lam <- -log(0.1) * 2.0
plot(function(x) pcrange(x, lam), 1/100, 10, n = 100)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.