| rgeneric-class | R Documentation |
INLA.A GMRF is defined from model parameters \theta that
would parametrize a (sparse) precision matrix.
The elements of a GMR are:
graph to define the non-zero precision matrix pattern.
only the upper triangle including the diagonal is needed.
Q vector where the
first element (N) is the size of the matrix,
second element (M) is the number of non-zero elements in the upper part (including) diagonal
the remaining (M) elements are the actual precision (upper triangle plus diagonal) elements whose order shall follow the graph definition.
mu the mean vector,
initial vector with
first element as the number of the parameters in the model
remaining elements should be the initials for the model parameters.
log.norm.const log of the normalizing constant.
log.prior log of the prior for the model parameters.
rgeneric(model, n, debug = FALSE, ...)
## Default S3 method:
rgeneric(model, n, debug = FALSE, ...)
## S3 method for class 'rgeneric'
rgeneric(model, ...)
## S3 method for class 'inla.rgeneric'
rgeneric(model, ...)
## S3 method for class 'rgeneric'
print(x, ...)
## S3 method for class 'rgeneric'
summary(object, ...)
## S3 method for class 'rgeneric'
plot(x, y, ...)
model |
an object used to define the model. See the 'rgeneric' vignette from the INLA package. |
n |
integer with the dimension of the model |
debug |
logical indicating debug state. |
... |
not used |
x |
a rgeneric object |
object |
a rgeneric object |
y |
not used |
rgeneric/ inla.rgeneric object.
rgeneric(default): The rgeneric default method.
rgeneric(rgeneric): Returns the model object unchanged.
rgeneric(inla.rgeneric): Check and converts a regular inla.rgeneric object to rgeneric.
print(rgeneric): Print the rgeneric object
summary(rgeneric): A summary for a rgeneric object
plot(rgeneric): A plot for a rgeneric object
Recommended for prototyping, whereas
cgeneric is recommended for production.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.